==> v1.1.2.0.zip: systemtraymenu/README.md <==
[![Build Status](https://dev.azure.com/MarkusHofknecht/SystemTrayMenu/_apis/build/status/Hofknecht.SystemTrayMenu?branchName=master)](https://dev.azure.com/MarkusHofknecht/SystemTrayMenu/_build)
[![Build Version](https://img.shields.io/github/v/release/hofknecht/systemtraymenu)](https://github.com/Hofknecht/SystemTrayMenu/releases) [![GitHub](https://github.com/favicon.ico)](https://github.com/Hofknecht/SystemTrayMenu/releases) [![Downloads GitHub](https://img.shields.io/github/downloads/Hofknecht/SystemTrayMenu/total.svg)](https://github.com/Hofknecht/SystemTrayMenu/releases)&nbsp;[![SourceForge](https://user-images.githubusercontent.com/52528841/89990756-1aff8000-dc83-11ea-828a-a70a4d567399.png)](https://sourceforge.net/projects/systemtraymenu/files/latest/download) [![Downloads SourceForge](https://img.shields.io/sourceforge/dt/systemtraymenu.svg)](https://sourceforge.net/projects/systemtraymenu/files/latest/download)&nbsp;

[![MicrosoftStore](https://user-images.githubusercontent.com/52528841/88452959-371db780-ce63-11ea-9076-11920156456a.png)](https://www.microsoft.com/store/apps/9N24F8ZBJMT1) 
[![majorgeeks](https://user-images.githubusercontent.com/52528841/116281616-2d2a3b80-a78a-11eb-948c-bde9a8ccb1ed.png)](https://www.majorgeeks.com/files/details/systemtraymenu.html) 
[![computerbild](https://user-images.githubusercontent.com/52528841/121583122-2735a480-ca30-11eb-82a4-b4f6054e4d8f.png)](https://www.computerbild.de/download/SystemTrayMenu-26748523.html) 
[![heise](https://user-images.githubusercontent.com/52528841/125174840-53c41400-e1c8-11eb-8992-2de3e078c7b2.png)](https://www.heise.de/download/product/systemtraymenu) 
[![CHIP](https://user-images.githubusercontent.com/52528841/88452975-5583b300-ce63-11ea-8256-6e69a2bb3e2d.png)](https://www.chip.de/downloads/SystemTrayMenu_182854219.html) 
[![softpedia](https://user-images.githubusercontent.com/52528841/121581852-a033fc80-ca2e-11eb-8aee-4a8cd3043bd1.png)](https://www.softpedia.com/get/System/Launchers-Shutdown-Tools/SystemTrayMenu.shtml) 
[![freeware-base](https://user-images.githubusercontent.com/52528841/136707080-a64c8eeb-d563-44e6-aee3-1fb2921221e0.png)](https://www.freeware-base.de/freeware-zeige-details-31811-SystemTrayMenu.html)
[![netzwelt](https://user-images.githubusercontent.com/52528841/121585548-015dcf00-ca33-11eb-8436-b1f5231d5c2d.png)](https://www.netzwelt.de/download/25705-systemtraymenu.html) 
[![aiiguide](https://user-images.githubusercontent.com/52528841/136708010-1f7a7d04-0b0b-4fe8-b70c-83bd48733d9c.png)](https://aiiguide.com/download-systemtraymenu.html)
[![taiwebs](https://user-images.githubusercontent.com/52528841/136708061-6384d536-88a7-4c5d-a13a-a1b0cff00e68.png)](https://de.taiwebs.com/windows/download-systemtraymenu-6812.html)
[![rjno1](https://user-images.githubusercontent.com/52528841/121582195-04ef5700-ca2f-11eb-9c22-cf8239c6e99b.png)](https://www.rjno1.com/systemtraymenu/) 
[![softaro](https://user-images.githubusercontent.com/52528841/121581997-c9548d00-ca2e-11eb-9145-fab017925475.png)](https://softaro.net/systemtraymenu/)
[![bytesin](https://user-images.githubusercontent.com/52528841/136706178-0bd2e812-f087-40f4-8c30-301ba645f10d.png)](https://www.bytesin.com/software/SystemTrayMenu/)
[![rsload](https://user-images.githubusercontent.com/52528841/121584316-a1b2f400-ca31-11eb-8a90-242b9ba80dc4.png)](https://rsload.net/soft/desktop/35219-systemtraymenu.html) 
[![softonic](https://user-images.githubusercontent.com/52528841/121586781-5a7a3280-ca34-11eb-8a03-618b4661f859.png)](https://systemtraymenu.en.softonic.com/) 
[![mirsofta](https://user-images.githubusercontent.com/52528841/121584682-0706e500-ca32-11eb-8629-4599579a1620.png)](https://mirsofta.ru/index.php?id=1623024195)
[![downloaddrivers](https://user-images.githubusercontent.com/52528841/116524789-0f6aec80-a8d8-11eb-9037-06b2c101fa72.png)](https://www.downloaddrivers.info/download-systemtraymenu-1-0-17-43/) 
[![baominh](https://user-images.githubusercontent.com/52528841/120082388-0c277400-c0c3-11eb-97c8-ee35e692b38d.png)](https://baominh.tech/systemtraymenu-tao-menu-start-tuy-chinh-duoi-khai-he-thong.html)
[![softodrom](https://user-images.githubusercontent.com/52528841/142266835-80248737-60d6-4e80-9ce3-e9b68bb217c0.png)](https://soft.softodrom.ru/%D0%A1%D0%BA%D0%B0%D1%87%D0%B0%D1%82%D1%8C/28225)

<!-- [![Gitter](https://badges.gitter.im/SystemTrayMenu/community.svg)](https://gitter.im/SystemTrayMenu/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge) -->

SystemTrayMenu<img src="https://raw.githubusercontent.com/Hofknecht/SystemTrayMenu/master/Resources/SystemTrayMenu.ico" alt="Trulli" width="24" height="24">  
------------------
**Browse and open your files easily**

SystemTrayMenu is a free, open-source start menu alternative for Microsoft Windows. It offers a clear, personalized menu in the system tray. Files, links and folders are organized in several levels as drop-down menus.

We are using C# and .NET 6 (.Net Core 3.1 in versions lower than 1.1.0.0)

![20200812_125923](https://user-images.githubusercontent.com/52528841/90009201-ee0c9680-dc9d-11ea-9b8a-b34108152f9b.gif)
![20200812_130823](https://user-images.githubusercontent.com/52528841/90009212-f1078700-dc9d-11ea-943a-d5fde4d6f2dc.gif)
[![Windows 11 neues Startmenü hinzufügen! - SystemTrayMenu _ PathTM - YouTube](https://img.youtube.com/vi/xsi4Uv3-ZLg/0.jpg)](https://www.youtube.com/watch?v=xsi4Uv3-ZLg)

Download the latest official version:  
https://github.com/Hofknecht/SystemTrayMenu/releases
  
Blogs and reviews
------------------
* https://www.deskmodder.de/blog/2020/07/18/systemtraymenu-nun-auch-als-windows-10-app-neben-der-portablen-version/
* https://www.trishtech.com/2020/07/systemtraymenu-is-simple-and-lightweight-start-menu-alternative/
* https://www.ghacks.net/2021/04/10/create-a-custom-start-menu-that-you-can-access-with-a-hotkey-using-systemtraymenu/
* http://www.shrayas.com/posts/quick-access-everything-with-systemtraymenu/
* https://reviewsapp.org/systemtraymenu-better-organization-of-windows
* https://teamos-hkrg.com/threads/systemtraymenu-1-0-20-0.162800/
* https://www.deskmodder.de/blog/2021/11/14/systemtraymenu-als-ersatz-fuer-die-symbolleiste-unter-windows-11/


FAQ
------------------

**What do I have to do now as first steps?**  

SystemTrayMenu is portable, so it does not need to be installed. After downloading e.g. SystemTrayMenu-1.0.17.24.zip, **unzip the folder**, then **start SystemTrayMenu.exe**.
If you prefer an installation there is the possibility to install SystemTrayMenu via the Windows Store.
  
1. Step: After starting the application the first time you have to **choose the root directory**.  
In this directory you should put shortcuts, files and folders (App, Game, Script, URL, Network),  
which you are often using and especially when you can not find them over the windows start menu search.  
You can also consider to put there all files from your desktop.  

2. Step: **Move the SystemTrayMenu icon** by drag and drop from the system tray **into the taskbar** below.  
![group icon out](https://user-images.githubusercontent.com/52528841/83349567-1ab74000-a336-11ea-8676-3db33615a57a.gif)

3. Step: Now it is ready to start - just **click on the icon** in the taskbar to open the SystemTrayMenu. 

**How can I change the root directory?**

You can change the root directory in the settings menu, that you can open by right clicking on the SystemTrayMenu icon.  

**What does the hotkey do?**

In the settings menu you can choose a hotkey to open and close the SystemTrayMenu.  

**Can the SystemTrayMenu launch on windows startup?**

Yes, you can select this option in the settings menu, that you can open by right clicking on the SystemTrayMenu icon.  

**What can I do if I have a problem, idea or question?**

If a problem has occured or you have any ideas or questions, you are welcome to contact us.  
Create an issue or write us an email [Markus Hofknecht](Markus@Hofknecht.de)

**Find more FAQ topics here:**
[SystemTrayMenu FAQ](https://github.com/Hofknecht/SystemTrayMenu/issues?q=is%3Aissue+is%3Aclosed+label%3AFAQ)


Security
------------------

Some antiviruses might flag this program as malicious, but it is not! The source is open, so you can compile it yourself.  


Build
------------------

Install Visual Studio 2022.  
Install .NET 6 SDK [https://dotnet.microsoft.com](https://dotnet.microsoft.com/download/dotnet/6.0).

Contributing
------------------

If you would like to contribute, everyone is welcome to.  
If you are considering a feature, need guidance, or want to talk about an idea, don't hesitate to create an issue here.  
When contributing please respect the style used by the codebase and consider the following rules:  
* Run FixCop.  
* Increase the version in the assembly file.  
* Add a commit message like: 
```
[Feature] Show icon in taskbar when application is running (#115), version 0.11.1.9
```

* Commit either directly to the master branch or create a new branch if you are not sure with your changes 
https://guides.github.com/activities/hello-world/.  
* Update the issue and set the status to closed.  

Contributors
------------------

Special thanks to our productive contibutors!
* [Tanja Hofknecht](https://github.com/Tanjalibertatis)
* [Peter Kirmeier](https://github.com/topeterk)

Thanks for ideas, reporting issues and contributing!

[Mario Sedlmayr](https://github.com/verdammt89x),
#123 [Mordecai00](https://github.com/Mordecai00), 
#125 [Holgermh](https://github.com/Holgermh), 
#135 #153 #154 #164 [jakkaas](https://github.com/jakkaas), 
#145 [Pascal Aloy](mailto:paloy@wanadoo.fr), 
#153 #158 #160 [blackcrack](https://github.com/blackcrack), 
#162 [HansieNL](https://github.com/HansieNL), 
#163 [igorruckert](https://github.com/igorruckert), 
#171 [kehoen](https://github.com/kehoen), 
#186 [Dtrieb](https://github.com/Dtrieb), 
#188 #189 #191 #195 [iJahangard](https://github.com/iJahangard),
#195 #197 #238 [the-phuctran](https://github.com/the-phuctran),
#205 [kristofzerbe](https://github.com/kristofzerbe), 
#209 [jonaskohl](https://github.com/jonaskohl), 
#211 [blacksparrow15](https://github.com/blacksparrow15),
#220 [Yavuz E.](mailto:yavuzelektronik@gmail.com),
#229 #230 #239 [Peter O.](pohle@htp-tel.de),
#231 [Ryonez](https://www.youtube.com/user/Ryonez), 
#235 #242 243 #247 Tom, 
#237 Torsten S.,
#240 [video](https://www.youtube.com/watch?v=xsi4Uv3-ZLg) [Patrick](https://www.youtube.com/user/DyRexLP),
#244 Gunter D.
#246 [MACE4GITHUB](https://github.com/MACE4GITHUB), and many more ... (please give us a hint if we missed someone)

Donations
------------------

We would be delighted if you could help us with the following:
* star on this github project
* share or like [video](https://www.youtube.com/watch?v=xsi4Uv3-ZLg)
* join or like us on [reddit](https://www.reddit.com/r/SystemTrayMenu/) and/or [Facebook](https://www.facebook.com/Systemtraymenu-114069060335483)
* review or rating on [Sourceforge](https://sourceforge.net/projects/systemtraymenu/) or somewhere else
* your ideas either as issues here in github or directly per mail

Don't hesitate to donate if you appreciate SystemTrayMenu and would like to support our work.  
[![PayPal](https://www.paypalobjects.com/webstatic/de_DE/i/de-pp-logo-100px.png)](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=Y9W6H5HXQPPUQ&source=url)

Sponsors - Thank you!
------------------

* Ralf K.
* Maximilian H.

==> v1.2.2.0.zip: systemtraymenu/README.md <==
[![Build Status](https://dev.azure.com/MarkusHofknecht/SystemTrayMenu/_apis/build/status/Hofknecht.SystemTrayMenu?branchName=master)](https://dev.azure.com/MarkusHofknecht/SystemTrayMenu/_build)
[![Build Version](https://img.shields.io/github/v/release/hofknecht/systemtraymenu)](https://github.com/Hofknecht/SystemTrayMenu/releases) [![GitHub](https://github.com/favicon.ico)](https://github.com/Hofknecht/SystemTrayMenu/releases) [![Downloads GitHub](https://img.shields.io/github/downloads/Hofknecht/SystemTrayMenu/total.svg)](https://github.com/Hofknecht/SystemTrayMenu/releases)&nbsp;[![SourceForge](https://user-images.githubusercontent.com/52528841/89990756-1aff8000-dc83-11ea-828a-a70a4d567399.png)](https://github.com/Hofknecht/SystemTrayMenu/releases) [![Downloads SourceForge](https://img.shields.io/sourceforge/dt/systemtraymenu.svg)](https://github.com/Hofknecht/SystemTrayMenu/releases)&nbsp;

[![MicrosoftStore](https://user-images.githubusercontent.com/52528841/88452959-371db780-ce63-11ea-9076-11920156456a.png)](https://www.microsoft.com/store/apps/9N24F8ZBJMT1) 
[![majorgeeks](https://user-images.githubusercontent.com/52528841/116281616-2d2a3b80-a78a-11eb-948c-bde9a8ccb1ed.png)](https://www.majorgeeks.com/files/details/systemtraymenu.html) 
[![computerbild](https://user-images.githubusercontent.com/52528841/121583122-2735a480-ca30-11eb-82a4-b4f6054e4d8f.png)](https://www.computerbild.de/download/SystemTrayMenu-26748523.html) 
[![heise](https://user-images.githubusercontent.com/52528841/125174840-53c41400-e1c8-11eb-8992-2de3e078c7b2.png)](https://www.heise.de/download/product/systemtraymenu) 
[![CHIP](https://user-images.githubusercontent.com/52528841/88452975-5583b300-ce63-11ea-8256-6e69a2bb3e2d.png)](https://www.chip.de/downloads/SystemTrayMenu_182854219.html) 
[![softpedia](https://user-images.githubusercontent.com/52528841/121581852-a033fc80-ca2e-11eb-8aee-4a8cd3043bd1.png)](https://www.softpedia.com/get/System/Launchers-Shutdown-Tools/SystemTrayMenu.shtml) 
[![freeware-base](https://user-images.githubusercontent.com/52528841/136707080-a64c8eeb-d563-44e6-aee3-1fb2921221e0.png)](https://www.freeware-base.de/freeware-zeige-details-31811-SystemTrayMenu.html)
[![netzwelt](https://user-images.githubusercontent.com/52528841/121585548-015dcf00-ca33-11eb-8436-b1f5231d5c2d.png)](https://www.netzwelt.de/download/25705-systemtraymenu.html) 
[![aiiguide](https://user-images.githubusercontent.com/52528841/136708010-1f7a7d04-0b0b-4fe8-b70c-83bd48733d9c.png)](https://aiiguide.com/download-systemtraymenu.html)
[![taiwebs](https://user-images.githubusercontent.com/52528841/136708061-6384d536-88a7-4c5d-a13a-a1b0cff00e68.png)](https://de.taiwebs.com/windows/download-systemtraymenu-6812.html)
[![rjno1](https://user-images.githubusercontent.com/52528841/121582195-04ef5700-ca2f-11eb-9c22-cf8239c6e99b.png)](https://www.rjno1.com/systemtraymenu/) 
[![softaro](https://user-images.githubusercontent.com/52528841/121581997-c9548d00-ca2e-11eb-9145-fab017925475.png)](https://softaro.net/systemtraymenu/)
[![bytesin](https://user-images.githubusercontent.com/52528841/136706178-0bd2e812-f087-40f4-8c30-301ba645f10d.png)](https://www.bytesin.com/software/SystemTrayMenu/)
[![rsload](https://user-images.githubusercontent.com/52528841/121584316-a1b2f400-ca31-11eb-8a90-242b9ba80dc4.png)](https://rsload.net/soft/desktop/35219-systemtraymenu.html) 
[![softonic](https://user-images.githubusercontent.com/52528841/121586781-5a7a3280-ca34-11eb-8a03-618b4661f859.png)](https://systemtraymenu.en.softonic.com/) 
[![mirsofta](https://user-images.githubusercontent.com/52528841/121584682-0706e500-ca32-11eb-8629-4599579a1620.png)](https://mirsofta.ru/index.php?id=1623024195)
[![downloaddrivers](https://user-images.githubusercontent.com/52528841/116524789-0f6aec80-a8d8-11eb-9037-06b2c101fa72.png)](https://www.downloaddrivers.info/download-systemtraymenu-1-0-17-43/) 
[![baominh](https://user-images.githubusercontent.com/52528841/120082388-0c277400-c0c3-11eb-97c8-ee35e692b38d.png)](https://baominh.tech/systemtraymenu-tao-menu-start-tuy-chinh-duoi-khai-he-thong.html)
[![softodrom](https://user-images.githubusercontent.com/52528841/142266835-80248737-60d6-4e80-9ce3-e9b68bb217c0.png)](https://soft.softodrom.ru/%D0%A1%D0%BA%D0%B0%D1%87%D0%B0%D1%82%D1%8C/28225)

<!-- [![Gitter](https://badges.gitter.im/SystemTrayMenu/community.svg)](https://gitter.im/SystemTrayMenu/community?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge) -->

SystemTrayMenu<img src="https://raw.githubusercontent.com/Hofknecht/SystemTrayMenu/master/Resources/SystemTrayMenu.ico" alt="Trulli" width="24" height="24">  
------------------
**Browse and open your files easily**

SystemTrayMenu is a free, open-source start menu alternative for Microsoft Windows. It offers a clear, personalized menu in the system tray. Files, links and folders are organized in several levels as drop-down menus.

We are using C# and .NET 6.

![20211211_170852](https://user-images.githubusercontent.com/52528841/145683690-5b25bc43-a497-4cf0-9c16-947a2d2dcd77.gif)

[![Windows 11 neues Startmenü hinzufügen! - SystemTrayMenu _ PathTM - YouTube](https://user-images.githubusercontent.com/52528841/145684486-44e98d8f-c2ba-42fa-837d-91a6a397549a.png)](https://www.youtube.com/watch?v=xsi4Uv3-ZLg)

Download the latest official version:  
https://github.com/Hofknecht/SystemTrayMenu/releases
  
Blogs and reviews
------------------
* https://www.deskmodder.de/blog/2020/07/18/systemtraymenu-nun-auch-als-windows-10-app-neben-der-portablen-version/
* https://www.trishtech.com/2020/07/systemtraymenu-is-simple-and-lightweight-start-menu-alternative/
* https://www.ghacks.net/2021/04/10/create-a-custom-start-menu-that-you-can-access-with-a-hotkey-using-systemtraymenu/
* http://www.shrayas.com/posts/quick-access-everything-with-systemtraymenu/
* https://reviewsapp.org/systemtraymenu-better-organization-of-windows
* https://www.white-windows.ru/systemtraymenu-podobie-menyu-pusk-no-bolee-prostoe-i-rabotayushhee-iz-sistemnogo-treya/
* https://teamos-hkrg.com/threads/systemtraymenu-1-0-20-0.162800/
* https://www.deskmodder.de/blog/2021/11/14/systemtraymenu-als-ersatz-fuer-die-symbolleiste-unter-windows-11/
* https://www.thewindowsclub.com/systemtraymenu-for-windows
* https://br.atsit.in/id/?p=100192
* https://www.netties.be/v20/toon_artikel.php?id=34684&cat=Software&zoekdatum=2021-12-13
* http://www.hackdos.com/62.html
* https://www.nesabamedia.com/systemtraymenu-alternatif-start-menu-untuk-windows/
* https://tweaks.com/news/3548904/systemtraymenu-is-a-free-start-menu-alternative-for-windows-1110/

FAQ
------------------

**What do I have to do now as first steps?**  

SystemTrayMenu is portable, so it does not need to be installed. After downloading e.g. SystemTrayMenu-1.0.17.24.zip, **unzip the folder**, then **start SystemTrayMenu.exe**. If you prefer an installation there is the possibility to install SystemTrayMenu via the Windows Store. 

If not already installed, then install .Net 6 [https://dotnet.microsoft.com](https://dotnet.microsoft.com/download/dotnet/6.0) (e.g. dotnet-sdk-6.0.100-win-x64.exe). 
  
1. Step: After starting the application the first time you have to **choose the root directory**.  
In this directory you should put shortcuts, files and folders (App, Game, Script, URL, Network),  
which you are often using and especially when you can not find them over the windows start menu search.  
You can also consider to put there all files from your desktop.  

2. Step: **Move the SystemTrayMenu icon** by drag and drop from the system tray **into the taskbar** below.  
![group icon out](https://user-images.githubusercontent.com/52528841/83349567-1ab74000-a336-11ea-8676-3db33615a57a.gif)

3. Step: Now it is ready to start - just **click on the icon** in the taskbar to open the SystemTrayMenu. 

**How can I change the root directory?**

You can change the root directory in the settings menu, that you can open by right clicking on the SystemTrayMenu icon.  

**What does the hotkey do?**

In the settings menu you can choose a hotkey to open and close the SystemTrayMenu.  

**Can the SystemTrayMenu launch on windows startup?**

Yes, you can select this option in the settings menu, that you can open by right clicking on the SystemTrayMenu icon.  

**What can I do if I have a problem, idea or question?**

If a problem has occured or you have any ideas or questions, you are welcome to contact us.  
[Create an issue](https://github.com/Hofknecht/SystemTrayMenu/issues/new/choose) or write us an email [Markus Hofknecht](Markus@Hofknecht.de)

**Find more FAQ topics here:**
[SystemTrayMenu FAQ](https://github.com/Hofknecht/SystemTrayMenu/issues?q=is%3Aissue+is%3Aclosed+label%3AFAQ)


Security
------------------

Some antiviruses might flag this program as malicious, but it is not! The source is open, so you can compile it yourself.  


Build
------------------

Install Visual Studio 2022.  
Install .NET 6 SDK [https://dotnet.microsoft.com](https://dotnet.microsoft.com/download/dotnet/6.0).
(.Net Core 3.1 in versions lower than 1.1.0.0)

Contributing
------------------

If you would like to contribute, everyone is welcome to.  
If you are considering a feature, need guidance, or want to talk about an idea, don't hesitate to create an issue here.  
When contributing please respect the style used by the codebase and consider the following rules:  
* Run FixCop.  
* Increase the version in the assembly file.  
* Add a commit message like: 
```
[Feature] Show icon in taskbar when application is running (#115), version 0.11.1.9
```

* Commit either directly to the master branch or create a new branch if you are not sure with your changes 
https://guides.github.com/activities/hello-world/.  
* Update the issue and set the status to closed.  

Contributors
------------------

Special thanks to our productive contibutors!
* [Tanja Hofknecht](https://github.com/Tanjalibertatis)
* [Peter Kirmeier](https://github.com/topeterk)

Thanks for ideas, reporting issues and contributing!

[Mario Sedlmayr](https://github.com/verdammt89x),
#123 [Mordecai00](https://github.com/Mordecai00), 
#125 [Holgermh](https://github.com/Holgermh), 
#135 #153 #154 #164 [jakkaas](https://github.com/jakkaas), 
#145 [Pascal Aloy](mailto:paloy@wanadoo.fr), 
#153 #158 #160 [blackcrack](https://github.com/blackcrack), 
#162 [HansieNL](https://github.com/HansieNL), 
#163 [igorruckert](https://github.com/igorruckert), 
#171 [kehoen](https://github.com/kehoen), 
#186 [Dtrieb](https://github.com/Dtrieb), 
#188 #189 #191 #195 [iJahangard](https://github.com/iJahangard),
#195 #197 #238 [the-phuctran](https://github.com/the-phuctran),
#205 [kristofzerbe](https://github.com/kristofzerbe), 
#209 [jonaskohl](https://github.com/jonaskohl), 
#211 [blacksparrow15](https://github.com/blacksparrow15),
#220 [Yavuz E.](mailto:yavuzelektronik@gmail.com),
#229 #230 #239 [Peter O.](pohle@htp-tel.de),
#231 [Ryonez](https://www.youtube.com/user/Ryonez), 
#235 #242 243 #247, #271 Tom, 
#237 Torsten S.,
#240 [video](https://www.youtube.com/watch?v=xsi4Uv3-ZLg) [Patrick](https://www.youtube.com/user/DyRexLP),
#244 Gunter D.,
#246 [MACE4GITHUB](https://github.com/MACE4GITHUB),
#259 [vanjac](https://github.com/vanjac),
#262 [terencemcdonnell](https://github.com/terencemcdonnell),
#269 [petersnows25](https://github.com/petersnows25),
#272 Peter M.,
#273 #274 [ParasiteDelta](https://github.com/ParasiteDelta),
#275 #276 #278 [donaldaken](https://github.com/donaldaken),
#277 Jan S.,
#282 [akuznets](https://github.com/akuznets),
#283 #284 #289 [RuSieg](https://github.com/RuSieg),
#285 #286 [dao-net](https://github.com/dao-net),
#288 William P.,


Donations
------------------
Use our Amazon Partner Link: https://amzn.to/3DOjTBa (As an Amazon partner, we earn from qualified sales.)

We would be delighted if you could help us with the following:
* star on this github project
* share or like [youtube video](https://www.youtube.com/watch?v=xsi4Uv3-ZLg)
* join or like us on [reddit](https://www.reddit.com/r/SystemTrayMenu/) and/or [Facebook](https://www.facebook.com/Systemtraymenu-114069060335483)
* review or rating on [Sourceforge](https://sourceforge.net/projects/systemtraymenu/) or somewhere else
* your ideas either as issues here in github or directly per mail

Don't hesitate to donate if you appreciate SystemTrayMenu and would like to support our work.  
[![PayPal](https://www.paypalobjects.com/webstatic/de_DE/i/de-pp-logo-100px.png)](https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=Y9W6H5HXQPPUQ&source=url)

Sponsors - Thank you!
------------------
* Ralf K.
* Maximilian H.
* [donaldaken](https://github.com/donaldaken)
